nsj_design_system library

Classes

AbstractFilteredList<E>
Properties and methods extended to List.
AdaptiveRedirectorPage
AnaColors
AnaColorTheme
AnaTextStyles
AnaTheme
AppBarEnd
AutocompleteTextField<T>
Arquivo autocomplete_textfield.dart
AutocompleteTextFormField<T>
Uma implementação de FormField do AutocompleteTextField, que permite salvar, validar, etc. o valor.
AutocompleteTextFormFieldValidated<T>
BadgeLabel
CalendarDatePicker2
CalendarDatePicker2Config
Custom configuration for CalendarDatePicker2
CalendarDatePicker2WithActionButtons
Display CalendarDatePicker with action buttons
CalendarDatePicker2WithActionButtonsConfig
Custom configuration for CalendarDatePicker2 with action buttons
CardWidget
ChipsTextField<T>
Um campo de texto com chips que exibe sugestões enquanto você digita.
ConfirmationModalWidget
CustomBaseTextField
CustomBasicAppBar
CustomCheckBoxWithText
CustomChip
CustomDatePicker
CustomDecimalTextInputFormatter
CustomDropdownFilterWidget<T>
CustomDropdownWidget<T>
CustomIconButton
CustomLinkButton
CustomListTile
CustomOutlinedButton
CustomPdfViewer
CustomPrimaryButton
CustomScaffold
CustomScaffoldController
CustomSegmentedButton
CustomTextButton
CutLeadingZerosFormatter
DataColumnWidget
DataRowWidget
DataTableWidget
DateDecoration
DateRangeTextFormFieldWidget
DateTextFormFieldWidget
DecisionModal
DoubleButtonsWidget
DoubleRangeFormatter
DoubleTextFormFieldWidget
ErrorHandler
ErrorModal
ExtraTextTheme
FaDuotoneIconData
FaIconData for a font awesome duotone icon.
FaIcon
Creates an Icon Widget that works for non-material Icons, such as the Font Awesome Icons.
FaIconData
A wrapper for IconData to ensure type safety and correct rendering with FaIcon.
FilteredList<E>
An extension class of List that applies a filter to a List and can access, modify, or delete the list in that state.
FilteredListRange
force the scope of the list
FilterHelper
FilterPopupState
State for calling filter pop
FontAwesomeIcons
Icons based on font awesome 7.2.0
GanttDateWidget
GanttEvent<E>
GanttEventWidget<E>
GanttIconButton
GanttLineWidget
GanttRow<T, E>
GridLineRecordWidget
HorizontalStepperWidget
INhidsGridState
IntegerTextFormFieldWidget
LanguageChangeWidget
LaunchpadAdaptiveRedirectorPage
LineDecoration
LineRecordWidget
LineSpacing
LinkedScrollControllerGroup
Sets up a collection of scroll controllers that mirror their movements to each other.
ListViewWithFooter
ListViewWithTwoColumns
MoneyTextFormFieldWidget
NhidsActionChip
NhidsAdaptive
NhidsAggregateColumnFooter
Widget for outputting the sum, average, minimum, and maximum values of all values in a column.
NhidsAggregateColumnFooterState
NhidsAggregateHelper
NhidsAnimationSplashAna
NhidsAnimationSplashGeneric
NhidsAutoSize<T>
NhidsAutoSizeEqual<T>
Change the width of the items equally within the maxSize range.
NhidsAutoSizeHelper
Returns the auto-sizing class according to NhidsAutoSizeMode.equal or NhidsAutoSizeMode.scale.
NhidsAutoSizeScale<T>
Change the size of items according to the ratio.
NhidsCell<T>
NhidsChangeNotifier
NhidsChangeNotifierFilter<T>
NhidsChangeNotifierFilterResolver
NhidsClipboardTransformation
NhidsCodeMopeButton
NhidsColorTheme
NhidsColumn
NhidsColumnFooterRendererContext
NhidsColumnGroup
NhidsColumnGroupHelper
Helper class for handling NhidsColumnGroup.
NhidsColumnGroupPair
NhidsColumnMenuDelegate<T>
NhidsColumnMenuDelegateDefault
NhidsColumnRendererContext
NhidsColumnType<T>
NhidsColumnTypeHasDateFormat
NhidsColumnTypeHasFormat<T>
NhidsColumnTypeHasPopupIcon
NhidsDangerButton
NhidsDataColumn
NhidsDataRow
NhidsDataTable
NhidsDateFormField
NhidsDateTimeHelper
NhidsDebounce
NhidsDebounceByHashCode
NhidsDecimalFormField
NhidsDialog
NhidsDualGrid
NhidsDualGrid can connect the keyboard movement between the two grids by arranging two NhidsGrid left and right.
NhidsDualGridDisplay
NhidsDualGridDisplayExpandedAndFixed
NhidsDualGridDisplayFixedAndExpanded
NhidsDualGridDisplayRatio
NhidsDualGridDivider
In NhidsDualGrid, set the separation widget between the two grids.
NhidsDualGridDividerWidget
NhidsDualGridDividerWidgetState
NhidsDualGridLayoutDelegate
NhidsDualGridPopup
NhidsDualGridPopup can connect the keyboard movement between the two grids by arranging two NhidsGrid left and right. It works as a popup.
NhidsDualGridProps
NhidsDualGridResizeNotifier
NhidsDualGridState
NhidsDualOnSelectedEvent
NhidsErrorDetailPage
NhidsErrorModal
NhidsFilterChip
NhidsFilterType
NhidsFilterTypeContains
NhidsFilterTypeEndsWith
NhidsFilterTypeEquals
NhidsFilterTypeGreaterThan
NhidsFilterTypeGreaterThanOrEqualTo
NhidsFilterTypeLessThan
NhidsFilterTypeLessThanOrEqualTo
NhidsFilterTypeStartsWith
NhidsFooter
NhidsGantt<T, E>
NhidsGradientText
NhidsGrid
NhidsGrid is a widget that receives columns and rows and is expressed as a grid-type UI.
NhidsGridActionCopyValues
Copies the value of the current cell or the selected cell or row to the clipboard.
NhidsGridActionDefaultEnterKey
This action is the default action of the Enter key.
NhidsGridActionDefaultEscapeKey
This is the action in which the default behavior of the Escape key is set.
NhidsGridActionDefaultTab
This is the action in which the default action of the tab key is set.
NhidsGridActionFocusToColumnFilter
Move the focus from the current cell position to the filtering TextField of the corresponding column.
NhidsGridActionMoveCellFocus
Move the current cell focus in the direction direction.
NhidsGridActionMoveCellFocusByPage
Move the focus of the current cell page by page.
NhidsGridActionMoveCellFocusToEdge
Move the focus of the current cell to the end of the direction direction.
NhidsGridActionMoveSelectedCellFocus
Moves the selected focus in the direction direction in the cell or row selection state.
NhidsGridActionMoveSelectedCellFocusByPage
Moves the selection position page by page in cell or row selection mode.
NhidsGridActionMoveSelectedCellFocusToEdge
Moves the selected focus to the end of the direction direction in the cell or row selection state.
NhidsGridActionPasteValues
Pastes the copied values to the clipboard depending on the position of the current cell or row.
NhidsGridActionSelectAll
Select all cells or rows.
NhidsGridActionSetEditing
Set the current cell to edit state.
NhidsGridActionToggleColumnSort
Toggles the sort state of the column.
NhidsGridCannotMoveCurrentCellEvent
Occurs when the keyboard hits the end of the grid.
NhidsGridCellGestureEvent
NhidsCell This event handles the gesture of the widget.
NhidsGridCellPosition
NhidsGridChangeColumnFilterEvent
Event called when the value of the TextField that handles the filter under the column changes.
NhidsGridChangeColumnSortEvent
Event issued when the sort state of a column is changed.
NhidsGridColumnFilterConfig
NhidsGridColumnSizeConfig
Automatically change the column width or set the mode when changing the width.
NhidsGridConfiguration
NhidsGridCupertinoScrollbarState
NhidsGridDragRowsEvent
Event called when a row is dragged.
NhidsGridEvent
NhidsGridEventManager
NhidsGridFilterPopupHeader
NhidsGridKeyEventResult
2021-11-19 KeyEventResult.skipRemainingHandlers 동작 오류로 인한 임시 코드 이슈 해결 후 : 삭제
NhidsGridKeyManager
NhidsGridKeyPressed
NhidsGridLayoutDelegate
NhidsGridLocaleText
NhidsGridOnChangedEvent
Event called when the value of NhidsCell is changed.
NhidsGridOnColumnsMovedEvent
Argument of NhidsGrid.onColumnsMoved callback to move columns by dragging or receive left or right fixed events.
NhidsGridOnLoadedEvent
NhidsGrid.onLoaded Argument received by registering callback.
NhidsGridOnRowCheckedAllEvent
Argument of NhidsGrid.onRowChecked callback when all checkboxes of the column are tapped.
NhidsGridOnRowCheckedEvent
Argument of NhidsGrid.onRowChecked callback to receive row checkbox event.
NhidsGridOnRowCheckedOneEvent
Argument of NhidsGrid.onRowChecked callback when the checkbox of the row is tapped.
NhidsGridOnRowDoubleTapEvent
The argument of the NhidsGrid.onRowDoubleTap callback to receive the event of double-tapping the row.
NhidsGridOnRowSecondaryTapEvent
Argument of the NhidsGrid.onRowSecondaryTap callback to receive the event of tapping the row with the right mouse button.
NhidsGridOnRowsMovedEvent
Argument of NhidsGrid.onRowsMoved callback to receive the event of moving the row by dragging it.
NhidsGridOnSelectedEvent
This is the argument value of the NhidsGrid.onSelected callback that is called when the NhidsGrid.mode value is in select mode.
NhidsGridOnSortedEvent
Argument of NhidsGrid.onSorted callback for receiving column sort change event.
NhidsGridPagination
A widget for client-side pagination.
NhidsGridPaginationState
NhidsGridPopup
NhidsGridPopup calls NhidsGrid in the form of a popup.
NhidsGridScrollbarConfig
Allows to customise scrollbars "look and feel" The general feature is making vertical scrollbar draggable and therefore more useful for desktop systems. Set draggableScrollbar to true to achieve this behavior. Also changing isAlwaysShown to true is recommended for more usability at desktops.
NhidsGridScrollController
This is a class for handling horizontal and vertical scrolling of columns and rows of NhidsGrid.
NhidsGridScrollUpdateEvent
An event that occurs when dragging or moving after a long tap.
NhidsGridSelectingCellPosition
NhidsGridSetColumnFilterEvent
If the value of NhidsGridStateManager.filterOnlyEvent is true, an event is issued. NhidsInfinityScrollRows or NhidsLazyPagination Event for delegating filtering processing to widgets.
NhidsGridSettings
NhidsGridShortcut
Class for setting shortcut actions.
NhidsGridShortcutAction
Define the action by implementing the execute method as an action that can be mapped to a shortcut key.
NhidsGridState
NhidsGridStateChangeNotifier
NhidsGridStateManager
It manages the state of the NhidsGrid and contains methods used by the grid.
NhidsGridStyleConfig
NhidsGroupTabButton<T>
NhidsIcons
NhidsImages
NhidsInfinityScrollRows
When the end of the list is reached by scrolling, arrow keys, or PageDown key manipulation Add the response result to the grid by calling the fetch callback function.
NhidsInfinityScrollRowsRequest
Request data to get data when scrolling has reached the end.
NhidsInfinityScrollRowsResponse
The return value of the fetch callback function of NhidsInfinityScrollRow when the scroll reaches the end.
NhidsIntegerFormField
NhidsKeyManagerEvent
NhidsLazyPagination
Widget for processing lazy pagination.
NhidsLazyPaginationRequest
Request data for lazy pagination processing.
NhidsLazyPaginationResponse
Response data for lazy pagination.
NhidsLinearProgressIndicator
NhidsLoading
Widget that is displayed when loading is enabled with the NhidsGridStateManager.setShowLoading method.
NhidsLocalization
NhidsNavigationDrawer
Um widget de gaveta de navegação para o Nhids.
NhidsNavItem
Um item de navegação personalizado para o pacote de design Nhids.
NhidsNotifierEvent
NhidsNotifierEventForceUpdate
NhidsNotifierFilterResolverDefault
NhidsNProgress
NhidsNumberSelection
NhidsOptional<T>
A class for changing the value of a nullable property in a method such as copyWith.
NhidsOverlay
Classe para exibição de sobreposições personalizadas.
NhidsPagination
Widget que implementa uma funcionalidade de paginação customizada.
NhidsPrimaryButton
NhidsProfileChip
NhidsProgressIndicator
NhidsResize<T>
This is the implementation that must be inherited when implementing the class according to NhidsResizeMode.
NhidsResizeHelper
Returns a class for changing the width of a column, etc.
NhidsResizePushAndPull<T>
Changes the size of the object to be changed by offset and pushes or pulls the size of the remaining items.
NhidsResponseErrorUtil
NhidsResponsive
A classe NhidsResponsive oferece funcionalidades para tornar uma aplicação Flutter responsiva.
NhidsRow
NhidsRowColorContext
Argument of NhidsGrid.rowColumnCallback callback to dynamically change the background color of a row.
NhidsRowGroupByColumnDelegate
NhidsRowGroupDelegate
Abstract class that defines a base interface for grouping rows.
NhidsRowGroupHelper
Helper class for grouping rows.
NhidsRowGroupTreeDelegate
NhidsRowType
NhidsRowTypeGroup
NhidsRowTypeNormal
NhidsScaffold
NhidsScaffoldController
NhidsScaledCheckbox
NhidsScreenSize
NhidsScrollbar
NhidsScrollBehavior
Extension class for ScrollConfiguration.behavior of NhidsGrid.
NhidsSearchFormField
NhidsSearchGroup
NhidsSecondaryButton
NhidsSelectDateDialog
NhidsSelectDateRangeDialog
NhidsShadowContainer
NhidsShadowLine
NhidsSideSheet
NhidsSpan
NhidsSyncButton
NhidsSyncButtonController
NhidsSyncedScrollControllers
NhidsSyncedScrollControllersState
NhidsTabButton
NhidsTagChip
NhidsTertiaryButton
NhidsTextDataCell
NhidsTextFormField
NhidsTextSpan
NhidsTextTitle
NhidsTheme
NhidsToast
NhidsTranslation
NhidsTwoLine
NhidsTwoLineText
NhidsValueListenableBuilder
OnlyLetterAndNumberFormatter
OnlyLetterFormatter
PasswordTextField
ProfileImageWidget
Responsive
A classe Responsive representa as dimensões de largura e altura em um sistema responsivo.
SimpleButtonCardWidget
SimpleCardButton
SimpleCardWidget
StandardCard
StepperComponent
SyncedScrollControllers
SyncedScrollControllersState
TabButton<T>
TabStatusButton
TabStatusMenuWidget
TagWidget
TextFieldConfiguration
Supply an instance of this class to the TypeAhead.textFieldConfiguration property to configure the displayed text field
TextFormFieldWidget
TimeTextFormFieldWidget
UpperCaseTextFormatter
VerticalStepperWidget
WeekToggleButtonsWidget
YearPicker
A scrollable grid of years to allow picking a year.

Enums

CalendarDatePicker2Mode
Custom enum for a date picker mode including day, month, and year.
CalendarDatePicker2SemanticsLabel
Custom semantic label types
CalendarDatePicker2Type
Custom enum for a date picker type including single, multi, and range.
ColumnSize
ConnectionSyncStatusEnum
DateType
DaysOfWeekEnum
DescriptionOfDayType
NhidsActionChipType
NhidsAggregateColumnGroupedRowType
When grouping row is applied, set the condition of row to be aggregated.
NhidsAggregateColumnIterateRowType
Determine the condition of the rows to be included in the aggregation.
NhidsAggregateColumnType
Determine the aggregate type.
NhidsAutoSizeMode
This mode automatically changes the width of columns, etc.
NhidsColumnFrozen
NhidsColumnSize
NhidsColumnSort
NhidsColumnTextAlign
NhidsGridColumnMenuItem
Items in the context menu on the right side of the column
NhidsGridEnterKeyAction
Behavior of the Enter key when a cell is selected.
NhidsGridEventType
NhidsGridGestureType
NhidsGridLoadingLevel
When calling loading screen with NhidsGridStateManager.setShowLoading method Determines the level of loading.
NhidsGridMode
NhidsGridScrollUpdateDirection
NhidsGridSelectingMode
A type of selection mode when you select a row or cell in a grid by tapping and holding, then moving the pointer or selecting a row or cell in the grid with controls or shift and tap.
NhidsGridTabKeyAction
Tab key action type.
NhidsMoveDirection
NhidsResizeMode
This mode is for adjusting the size of columns, etc.
NhidsRowGroupDelegateType
Determines the grouping type of the row.
NhidsRowState
NhidsTagChipType
NhidsTextType
NhidsToastType
NhidsType
TypeEventPopupAction

Extensions

NhidsColumnTypeExtension on NhidsColumnType
NhidsResponsiveExtension on num
Extensão para tornar um número responsivo em altura e largura.
NhidsRowTypeExtension on NhidsRowType

Functions

describeIdentity(Object? object) String
getDayRowsCount(int year, int month, int firstDayOfWeekIndex) int
Get the number of rows required to display all days in a month.
getLocaleFullMonthFormat(Locale locale) → DateFormat
Get full month format for the given locale.
getLocaleShortMonthFormat(Locale locale) → DateFormat
Get short month format for the given locale.
getMonthFirstDayOffset(int year, int month, int firstDayOfWeekIndex) int
Get the number of days offset for the first day in a month.
objectRuntimeType(Object? object, String optimizedValue) String
shortHash(Object? object) String
showCalendarDatePicker2Dialog({required BuildContext context, required CalendarDatePicker2WithActionButtonsConfig config, required Size dialogSize, List<DateTime?> value = const [], BorderRadius? borderRadius, bool useRootNavigator = true, bool barrierDismissible = true, Color? barrierColor = Colors.black54, bool useSafeArea = true, Color? dialogBackgroundColor, RouteSettings? routeSettings, String? barrierLabel, TransitionBuilder? builder}) Future<List<DateTime?>?>
Display CalendarDatePicker with action buttons
showColumnMenu<T>({required BuildContext context, required Offset position, required List<PopupMenuEntry<T>> items, Color backgroundColor = Colors.white}) Future<T?>?
Open the context menu on the right side of the column.
splitList(List<LineRecordWidget> list, int crossAxisCount) List<List<LineRecordWidget>>

Typedefs

ChildWidgetCallback = Widget Function()
ConvertObjectToStringCallback<T> = String Function(T value)
CreateFooterCallBack = Widget Function(NhidsGridStateManager stateManager)
CreateHeaderCallBack = Widget Function(NhidsGridStateManager stateManager)
DayBuilder = Widget? Function({required DateTime date, BoxDecoration? decoration, bool? isDisabled, bool? isSelected, bool? isToday, TextStyle? textStyle})
Custom builder for the day widget
DayTextStylePredicate = TextStyle? Function({required DateTime date})
Predicate to determine the text style for a day.
EventCallback<T, E> = void Function(T value, E event)
EventDoubleTap<E> = void Function(E event)
EventHover<E> = void Function(E? value)
EventLongPress<E> = void Function(E event)
EventMessageTooltipCallback<E> = String Function(E value)
EventPopupCardCallback<E> = Widget Function(E value, VoidCallback closePopup)
EventTap<E> = void Function(E value)
EventTextStringCallback<E> = String Function(E value)
FilteredListFilter<E> = bool Function(E element)
Callback function to set in setFilter.
ModePickerBuilder = Widget? Function({bool? isMonthPicker, required DateTime monthDate, required CalendarDatePicker2Mode viewMode})
Builder for the mode picker widget
ModePickerTextHandler = String? Function({bool? isMonthPicker, required DateTime monthDate})
Handler for the text displayed in the mode picker
MonthBuilder = Widget? Function({BoxDecoration? decoration, bool? isCurrentMonth, bool? isDisabled, bool? isSelected, required int month, TextStyle? textStyle})
Custom builder for the month widget
NhidsAggregateFilter = bool Function(NhidsCell)
Returns whether to be filtered according to the value of NhidsCell.value.
NhidsColumnCheckReadOnly = bool Function(NhidsRow row, NhidsCell cell)
It dynamically determines whether the cells of the column are in the edit state.
NhidsColumnFooterRenderer = Widget Function(NhidsColumnFooterRendererContext context)
NhidsColumnRenderer = Widget Function(NhidsColumnRendererContext rendererContext)
NhidsColumnValueFormatter = String Function(dynamic value)
NhidsCompareFunction = bool Function({required String? base, required NhidsColumn column, required String? search})
base is the cell values of the column on which the search is based. search is the value entered by the user to search.
NhidsDualOnSelectedEventCallback = void Function(NhidsDualOnSelectedEvent event)
NhidsGridColumnFilterResolver = dynamic Function<T>()
NhidsGridResolveDefaultColumnFilter = NhidsFilterType Function(NhidsColumn column, NhidsGridColumnFilterResolver resolver)
NhidsInfinityScrollRowsFetch = Future<NhidsInfinityScrollRowsResponse> Function(NhidsInfinityScrollRowsRequest)
A callback function to implement when the scroll reaches the end.
NhidsLazyPaginationFetch = Future<NhidsLazyPaginationResponse> Function(NhidsLazyPaginationRequest)
Callback function to implement to add lazy pagination data.
NhidsNavigationSelected = void Function(int value)
NhidsOnChangedEventCallback = void Function(NhidsGridOnChangedEvent event)
NhidsOnColumnsMovedEventCallback = void Function(NhidsGridOnColumnsMovedEvent event)
NhidsOnLoadedEventCallback = void Function(NhidsGridOnLoadedEvent event)
NhidsOnRowCheckedEventCallback = void Function(NhidsGridOnRowCheckedEvent event)
NhidsOnRowDoubleTapEventCallback = void Function(NhidsGridOnRowDoubleTapEvent event)
NhidsOnRowSecondaryTapEventCallback = void Function(NhidsGridOnRowSecondaryTapEvent event)
NhidsOnRowsMovedEventCallback = void Function(NhidsGridOnRowsMovedEvent event)
NhidsOnSelectedEventCallback = void Function(NhidsGridOnSelectedEvent event)
NhidsOnSortedEventCallback = void Function(NhidsGridOnSortedEvent event)
NhidsRowColorCallback = Color Function(NhidsRowColorContext rowColorContext)
NhidsRowGroupOnToggled = void Function({required bool expanded, required NhidsRow row})
A callback that is called when a group row is expanded or collapsed.
NhidsValueWidgetBuilder = Widget Function(BuildContext context, List values, Widget? child)
PaginationChangedCallback = void Function(int value)
RowTextStringCallback<T> = String Function(T value)
ScrollViewMonthYearBuilder = Widget Function(DateTime monthDate)
Builder for the month and year in the scroll calendar view.
ScrollViewOnScrolling = void Function(double offset)
Callback for the scroll calendar view on scrolling
SelectableDayPredicate = bool Function(DateTime day)
Predicate to determine whether a day should be selectable.
SelectableMonthPredicate = bool Function(int year, int month)
Predicate to determine whether a month should be selectable.
SelectableYearPredicate = bool Function(int year)
Predicate to determine whether a year should be selectable.
SelectedRangeDecorationPredicate = BoxDecoration? Function({required DateTime dayToBuild, required BoxDecoration decoration, required bool isEndDate, required bool isStartDate})
Predicate to determine the day widget box decoration for a day in selected range
SelectedRangeHighlightBuilder = Widget? Function({required DateTime dayToBuild, required bool isEndDate, required bool isStartDate})
Function to provide full control over range picker highlight
SelectedTabButtonCallback<T> = void Function(T value)
SetFilterPopupHandler = void Function(NhidsGridStateManager? stateManager)
WeekdayLabelBuilder = Widget? Function({bool? isScrollViewTopHeader, required int weekday})
Custom builder for the weekday label widget
YearBuilder = Widget? Function({BoxDecoration? decoration, bool? isCurrentYear, bool? isDisabled, bool? isSelected, TextStyle? textStyle, required int year})
Custom builder for the year widget

Exceptions / Errors

NhidsError
NhidsFailure