DateRangeTextFormFieldWidget class

Inheritance

Constructors

DateRangeTextFormFieldWidget({Key? key, required String label, String? hintText, String? helperText = 'dd/mm/aaaa - dd/mm/aaaa', DateTime? initDateStart, DateTime? initDateEnd, DateTime? firstDate, DateTime? lastDate, bool shouldReturnNull = false, bool isRequiredField = false, DatePickerEntryMode initialEntryMode = DatePickerEntryMode.input, String? validator(String?)?, void dateTimeRange(DateTimeRange<DateTime>?)?, void start(DateTime?)?, void end(DateTime?)?})
const

Properties

dateTimeRange → void Function(DateTimeRange<DateTime>?)?
final
end → void Function(DateTime?)?
final
firstDate DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
final
hintText String?
final
initDateEnd DateTime?
final
initDateStart DateTime?
final
initialEntryMode DatePickerEntryMode
final
isRequiredField bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
final
lastDate DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldReturnNull bool
final
start → void Function(DateTime?)?
final
validator String? Function(String?)?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DateRangeTextFormFieldWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited