NhidsColumnGroupHelper class

Helper class for handling NhidsColumnGroup.

Constructors

NhidsColumnGroupHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

exists({required String field, required NhidsColumnGroup columnGroup}) bool
Returns whether field exists in columnGroup.
existsFromList({required String field, required List<NhidsColumnGroup> columnGroupList}) bool
Returns whether field exists in columnGroupList.
getGroupIfExistsFromList({required String field, required List<NhidsColumnGroup> columnGroupList}) NhidsColumnGroup?
Finds NhidsColumnGroup with field in columnGroupList and returns it. Returns null if not found.
getParentGroupIfExistsFromList({required String field, required List<NhidsColumnGroup> columnGroupList}) NhidsColumnGroup?
Find the parent class of field in columnGroupList and return it. Returns null if not found.
maxDepth({required List<NhidsColumnGroup> columnGroupList, int level = 0}) int
columnGroupList Returns the depth of how many levels the group has been set.
separateLinkedGroup({required List<NhidsColumnGroup> columnGroupList, required List<NhidsColumn> columns}) List<NhidsColumnGroupPair>
Separate groups according to the order of columns.