NhidsGridScrollUpdateEvent class
An event that occurs when dragging or moving after a long tap.
When the offset enters the area that needs to be scrolled, the scroll animation continues until the end of the scroll direction.
When scrolling animation is in progress and entering an area that does not require scrolling, the existing scroll animation is stopped.
If a point up event occurs while scroll animation is in progress, the caller calling this event must call NhidsGridScrollUpdateEvent.stopScroll to stop the animation.
- Inheritance
-
- Object
- NhidsGridEvent
- NhidsGridScrollUpdateEvent
Constructors
- NhidsGridScrollUpdateEvent({required Offset offset, NhidsGridScrollUpdateDirection scrollDirection = NhidsGridScrollUpdateDirection.all})
Properties
- duration → Duration?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- offset → Offset
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollDirection → NhidsGridScrollUpdateDirection
-
final
- type → NhidsGridEventType
-
finalinherited
Methods
-
handler(
NhidsGridStateManager stateManager) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
stopScroll(
NhidsGridStateManager stateManager, NhidsGridScrollUpdateDirection scrollDirection) → void