NhidsRowGroupByColumnDelegate class
- Inheritance
-
- Object
- NhidsRowGroupDelegate
- NhidsRowGroupByColumnDelegate
Constructors
-
NhidsRowGroupByColumnDelegate({required List<
NhidsColumn> columns, bool showFirstExpandableIcon = false, bool showCount = true, bool enableCompactCount = true, NhidsRowGroupOnToggled? onToggled})
Properties
-
columns
→ List<
NhidsColumn> -
Column to group by.
final
- countFormat → NumberFormat
-
finalinherited
- enableCompactCount → bool
-
Decide whether to simply display the number of child rows when showCount is true.
final
- enabled → bool
-
Returns whether the grouping function is activated.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- onToggled → NhidsRowGroupOnToggled?
-
A callback that is called when a group row is expanded or collapsed.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCount → bool
-
Decide whether to display the number of child rows in the cell
where the expand icon is displayed in the grouped state.
final
- showFirstExpandableIcon → bool
-
Decide whether to force the expand button to be displayed in the first cell.
final
- type → NhidsRowGroupDelegateType
-
Determines the grouping type of the row.
no setteroverride
-
visibleColumns
→ List<
NhidsColumn> -
Returns a non-hidden column from the column to be grouped.
no setter
Methods
-
compactNumber(
num count) → String -
Brief summary of numbers.
inherited
-
filter(
{required FilteredList< NhidsRow> rows, required FilteredListFilter<NhidsRow> ? filter}) → void -
Handle filtering of grouped rows.
override
-
isEditableCell(
NhidsCell cell) → bool -
Determines whether the cell is editable.
override
-
isExpandableCell(
NhidsCell cell) → bool -
Decide whether to show the extended button.
override
-
isRowGroupColumn(
NhidsColumn column) → bool - Returns whether the column is a grouping column.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sort(
{required NhidsColumn column, required FilteredList< NhidsRow> rows, required int compare(NhidsRow, NhidsRow)}) → void -
Handle sorting of grouped rows.
override
-
toGroup(
{required Iterable< NhidsRow> rows}) → List<NhidsRow> -
Handling for grouping rows.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited