NhidsSearchFormField class

Inheritance

Constructors

NhidsSearchFormField({Key? key, String? initialValue, String? hintText, String? helperText, FocusNode? focusNode, bool isEnabled = true, TextEditingController? controller, AutovalidateMode validateMode = AutovalidateMode.onUserInteraction, bool readOnly = false, Duration? changeDelayDuration, VoidCallback? onTap, ValueChanged<String>? onChanged, FormFieldValidator<String>? validator})
const

Properties

changeDelayDuration → Duration?
final
controller → TextEditingController?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
helperText → String?
final
hintText → String?
final
initialValue → String?
final
isEnabled → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged → ValueChanged<String>?
final
onTap → VoidCallback?
final
readOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateMode → AutovalidateMode
final
validator → FormFieldValidator<String>?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<NhidsSearchFormField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited