NhidsColumnGroupHelper class
Helper class for handling NhidsColumnGroup.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
exists(
{required String field, required NhidsColumnGroup columnGroup}) → bool -
Returns whether
fieldexists incolumnGroup. -
existsFromList(
{required String field, required List< NhidsColumnGroup> columnGroupList}) → bool -
Returns whether
fieldexists incolumnGroupList. -
getGroupIfExistsFromList(
{required String field, required List< NhidsColumnGroup> columnGroupList}) → NhidsColumnGroup? -
Finds NhidsColumnGroup with
fieldincolumnGroupListand returns it. Returnsnullif not found. -
getParentGroupIfExistsFromList(
{required String field, required List< NhidsColumnGroup> columnGroupList}) → NhidsColumnGroup? -
Find the parent class of
fieldincolumnGroupListand return it. Returnsnullif not found. -
maxDepth(
{required List< NhidsColumnGroup> columnGroupList, int level = 0}) → int -
columnGroupListReturns the depth of how many levels the group has been set. -
separateLinkedGroup(
{required List< NhidsColumnGroup> columnGroupList, required List<NhidsColumn> columns}) → List<NhidsColumnGroupPair> -
Separate groups according to the order of
columns.