NhidsDecimalFormField class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- NhidsDecimalFormField
Constructors
-
NhidsDecimalFormField({Key? key, required String label, double? initialValue, String? hintText, String? helperText, FocusNode? focusNode, bool validateOnFocusExit = false, bool isEnabled = true, TextInputType? keyboardType, TextEditingController? controller, AutovalidateMode validateMode = AutovalidateMode.onUserInteraction, bool isRequiredField = false, Widget? prefix, Widget? suffix, int decimalDigits = 2, String? prefixSymbol, String? suffixSymbol, TextStyle? style, TextAlignVertical? textAlignVertical, TextAlign textAlign = TextAlign.start, InputDecoration? decoration, bool showHidePrefixSymbol = true, bool showHideSuffixSymbol = true, Duration? changeDelayDuration, ValueChanged<
double> ? onChanged, ValueChanged<double?> ? onValueOrNull, FormFieldValidator<String> ? validator, VoidCallback? onTap, VoidCallback? onEditingComplete, AppPrivateCommandCallback? onAppPrivateCommand, ValueChanged<String> ? onFieldSubmitted, FormFieldSetter<String?> ? onSaved, TapRegionCallback? onTapOutside}) -
const
Properties
- changeDelayDuration → Duration?
-
final
- controller → TextEditingController?
-
final
- decimalDigits → int
-
final
- decoration → InputDecoration?
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
final
- hintText → String?
-
final
- initialValue → double?
-
final
- isEnabled → bool
-
final
- isRequiredField → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
final
- label → String
-
final
- onAppPrivateCommand → AppPrivateCommandCallback?
-
final
-
onChanged
→ ValueChanged<
double> ? -
final
- onEditingComplete → VoidCallback?
-
final
-
onFieldSubmitted
→ ValueChanged<
String> ? -
final
-
onSaved
→ FormFieldSetter<
String?> ? -
final
- onTap → VoidCallback?
-
final
- onTapOutside → TapRegionCallback?
-
final
-
onValueOrNull
→ ValueChanged<
double?> ? -
final
- prefix → Widget?
-
final
- prefixSymbol → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showHidePrefixSymbol → bool
-
final
- showHideSuffixSymbol → bool
-
final
- style → TextStyle?
-
final
- suffix → Widget?
-
final
- suffixSymbol → String?
-
final
- textAlign → TextAlign
-
final
- textAlignVertical → TextAlignVertical?
-
final
- validateMode → AutovalidateMode
-
final
- validateOnFocusExit → bool
-
final
-
validator
→ FormFieldValidator<
String> ? -
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< NhidsDecimalFormField> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited